<?php
/*
 * Registar post type: Facebook Page
 * Facebookページ用ポストタイプ
 */
register_post_type(
        'fb-page',
        array(
                'label'           => 'Facebookページ',
                'description'     => 'Facebookページに関するポストタイプです。',
                'public'          => true,
                'show_ui'         => true,
                'show_in_menu'    => true,
                'capability_type' => 'post',
                'hierarchical'    => true,
                'rewrite'         => array(
                        'slug'          => ''
                ),
                'query_var'       => true,
                'supports'        => array(
                        'title',
                        'editor',
                        'excerpt',
                        'trackbacks',
                        'custom-fields',
                        'comments',
                        'revisions',
                        'thumbnail',
                        'author',
                        'page-attributes'
                ),
                'labels' => array (
                          'name'                => 'Facebookページ',
                          'singular_name'       => 'Facebookページ',
                          'menu_name'           => 'Facebookページ',
                          'add_new'             => '新規追加',
                          'add_new_item'        => '新規Facebookページ追加',
                          'edit'                => '編集',
                          'edit_item'           => 'Facebookページを編集',
                          'new_item'            => '新規Facebookページ',
                          'view'                => '表示',
                          'view_item'           => 'Facebookページを表示',
                          'search_items'        => 'Facebookページ検索',
                          'not_found'           => '見つかりません',
                          'not_found_in_trash'  => 'ゴミ箱にはありません',
                          'parent'              => '親'
                          
                ),
                'exclude_from_search' => true
        )
);


/*
 * Divid Contents
 * Description: Wordpressのmoreを使いコンテンツを分割する
 */
function get_divided_content( $more_link_text = null, $stripteaser = 0, $more_file = '' ) {
        
        //get contents & filter
        $content = get_the_content( $more_link_text, $stripteaser, $more_file );
	$content = apply_filters( 'the_content', $content );
        $content = str_replace( ']]>', ']]&gt;', $content );
        
        //divided contents
        $regex  = '#(<p><span id="more-[\d]+"></span></p>|<span id="more-[\d]+"></span>)#';
	if ( preg_match( $regex, $content ) ) {
                //set array
                list( $content_array['before'], $content_array['after'] ) = preg_split( $regex, $content, 2 );
        } else {
		$content_array['before'] = '';
		$content_array['after']  = $content;
        }
        
	return $content_array;
}


/*
 * add custom setting.
 * Facebook Application ID/Secret Keyの設定フォームを作る
 */
 
//Add whitelist
function add_custom_whitelist_options_fields( $whitelist_options ) {
        //項目名の設定（複数設定させたい場合はこの部分で複数設定すれば良い）
        //一般設定以外にもdiscussion、media、privacy、reading、writing、optionsのいずれかを設定することで他の設定にも指定可能
        $whitelist_options['general'][] = 'fb_app_id';
        $whitelist_options['general'][] = 'fb_app_key';
        
        return $whitelist_options;
}
add_filter( 'whitelist_options', 'add_custom_whitelist_options_fields' );

//add settings field
function add_general_custom_fields() {
        //add_settings_field( "ホワイトリストで指定した項目名", "ラベルタイトル", "コールバック用関数（フォーム生成）", "設定画面（ホワイトリストに準ずる）", "セクション", array( "label_for" => "ラベルID" ) );
        add_settings_field(
                "fb_app_id",
                "Facebook Application ID",
                'custom_fb_app_id',
                'general',
                'default',
                array(
                        'label_for' => 'fb_app_id'
                )
        );
        add_settings_field(
                "fb_app_key",
                "Facebook Application Secret Key（アプリの秘訣）",
                'custom_fb_app_key',
                'general',
                'default',
                array(
                        'label_for' => 'fb_app_key'
                )
        );
}
add_action( 'admin_init', 'add_general_custom_fields' );
 
//add input field
function custom_fb_app_id( $args ) {
    //保存されているデータを取得する
    $fb_app_id = get_option( 'fb_app_id' );
    //ホワイトリストに登録した項目名をベースにインプット要素を作る。もちろんセレクトボックスやラジオボタンなども可能（ただし、ファイルのアップロードは不可）
    echo '<input type="password" id="fb_app_id" name="fb_app_id" value="' . $fb_app_id . '" />';
}

function custom_fb_app_key( $args ) {
    //保存されているデータを取得する
    $fb_app_key = get_option( 'fb_app_key' );
    //ホワイトリストに登録した項目名をベースにインプット要素を作る。もちろんセレクトボックスやラジオボタンなども可能（ただし、ファイルのアップロードは不可）
    echo '<input type="password" id="fb_app_key" name="fb_app_key" value="' . $fb_app_key . '" />';
}
